[Zope-Checkins] CVS: ZODB3/ZEO - mkzeoinst.py:1.12

Guido van Rossum guido@python.org
Wed, 29 Jan 2003 17:19:12 -0500


Update of /cvs-repository/ZODB3/ZEO
In directory cvs.zope.org:/tmp/cvs-serv21688

Modified Files:
	mkzeoinst.py 
Log Message:
Change runner template and filename so as to be specific to the ZEO
package.


=== ZODB3/ZEO/mkzeoinst.py 1.11 => 1.12 ===
--- ZODB3/ZEO/mkzeoinst.py:1.11	Thu Jan 23 15:33:35 2003
+++ ZODB3/ZEO/mkzeoinst.py	Wed Jan 29 17:19:09 2003
@@ -20,9 +20,9 @@
 options (all of which have default values), create the following:
 
 <home>/etc/zeo.conf     -- ZEO config file
-<home>/etc/runner.conf  -- zdctl+zdrun config file
+<home>/etc/zeoctl.conf  -- zdctl+zdrun config file
 <home>/var/             -- Directory for data files: Data.fs etc.
-<home>/log/             -- Directory for log files: zeo.log and runner.log
+<home>/log/             -- Directory for log files: zeo.log and zeoctl.log
 <home>/bin/zeoctl       -- start/stop script (a shim for zdctl.py)
 
 The script will not overwrite existing files; instead, it will issue a
@@ -65,7 +65,7 @@
 </eventlog>
 """
 
-runner_conf_template = """# runner configuration file
+runner_conf_template = """# %(package)sctl configuration file
 
 <runner>
   program %(server)s -C %(home)s/etc/%(package)s.conf
@@ -87,7 +87,7 @@
 <eventlog>
   level info
   <logfile>
-    path %(home)s/log/runner.log
+    path %(home)s/log/%(package)sctl.log
   </logfile>
 </eventlog>
 """
@@ -103,7 +103,7 @@
 # chkconfig: 345 90 10
 # description: start a %(PACKAGE)s server
 
-exec %(zdctl)s -C %(home)s/etc/runner.conf ${1+"$@"}
+exec %(zdctl)s -C %(home)s/etc/%(package)sctl.conf ${1+"$@"}
 """
 
 def main():
@@ -139,7 +139,7 @@
     makedir(home, "log")
     makedir(home, "bin")
     makefile(zeo_conf_template, home, "etc", "zeo.conf", **params)
-    makefile(runner_conf_template, home, "etc", "runner.conf", **params)
+    makefile(runner_conf_template, home, "etc", "zeoctl.conf", **params)
     makexfile(zdctl_template, home, "bin", "zeoctl", **params)
     print "All done."